==> haskell-pipes-4.3.14-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pipes
version:              4.3.14
visibility:           public
id:                   pipes-4.3.14-EzRUkCm3DiVFTqLklN15x6
key:                  pipes-4.3.14-EzRUkCm3DiVFTqLklN15x6
license:              BSD-3-Clause
copyright:            2012-2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Compositional pipelines
description:
    `pipes` is a clean and powerful stream processing library that lets you build
    and connect reusable streaming components

    Advantages over traditional streaming libraries:

    * /Concise API/: Use simple commands like '\''for'\'', ('\''>->'\''), '\''await'\'', and '\''yield'\''

    * /Blazing fast/: Implementation tuned for speed, including shortcut fusion

    * /Lightweight Dependency/: @pipes@ is small and compiles very rapidly,
    including dependencies

    * /Elegant semantics/: Use practical category theory

    * /ListT/: Correct implementation of '\''ListT'\'' that interconverts with pipes

    * /Bidirectionality/: Implement duplex channels

    * /Extensive Documentation/: Second to none!

    Import "Pipes" to use the library.

    Read "Pipes.Tutorial" for an extensive tutorial.

category:             Control, Pipes
abi:                  8677bb6a24ee6359c69a40542e84048b
exposed:              True
exposed-modules:
    Pipes Pipes.Core Pipes.Internal Pipes.Lift Pipes.Prelude
    Pipes.Tutorial

import-dirs:          /usr/lib/ghc-8.10.2/site-local/pipes-4.3.14
library-dirs:         /usr/lib/ghc-8.10.2/site-local/pipes-4.3.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/pipes-4.3.14
hs-libraries:         HSpipes-4.3.14-EzRUkCm3DiVFTqLklN15x6
depends:
    base-4.14.1.0 exceptions-0.10.4 mmorph-1.1.3-25ar5RJCkQ8HgHLvsJHAi7
    mtl-2.2.2 transformers-0.5.6.2 void-0.7.3-FJLCa6y31Qt20kSi8TCcBC

haddock-interfaces:   /usr/share/doc/haskell-pipes/html/pipes.haddock
haddock-html:         /usr/share/doc/haskell-pipes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-4.3.14-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pipes
version:              4.3.14
visibility:           public
id:                   pipes-4.3.14-1Z2xeblbUgh96vnadPBGFf
key:                  pipes-4.3.14-1Z2xeblbUgh96vnadPBGFf
license:              BSD-3-Clause
copyright:            2012-2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Compositional pipelines
description:
    `pipes` is a clean and powerful stream processing library that lets you build
    and connect reusable streaming components

    Advantages over traditional streaming libraries:

    * /Concise API/: Use simple commands like '\''for'\'', ('\''>->'\''), '\''await'\'', and '\''yield'\''

    * /Blazing fast/: Implementation tuned for speed, including shortcut fusion

    * /Lightweight Dependency/: @pipes@ is small and compiles very rapidly,
    including dependencies

    * /Elegant semantics/: Use practical category theory

    * /ListT/: Correct implementation of '\''ListT'\'' that interconverts with pipes

    * /Bidirectionality/: Implement duplex channels

    * /Extensive Documentation/: Second to none!

    Import "Pipes" to use the library.

    Read "Pipes.Tutorial" for an extensive tutorial.

category:             Control, Pipes
abi:                  067934dee478e71a02d1cf8b5118c219
exposed:              True
exposed-modules:
    Pipes Pipes.Core Pipes.Internal Pipes.Lift Pipes.Prelude
    Pipes.Tutorial

import-dirs:          /usr/lib/ghc-8.10.2/site-local/pipes-4.3.14
library-dirs:         /usr/lib/ghc-8.10.2/site-local/pipes-4.3.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/pipes-4.3.14
hs-libraries:         HSpipes-4.3.14-1Z2xeblbUgh96vnadPBGFf
depends:
    base-4.14.1.0 exceptions-0.10.4 mmorph-1.1.3-25ar5RJCkQ8HgHLvsJHAi7
    mtl-2.2.2 transformers-0.5.6.2 void-0.7.3-FJLCa6y31Qt20kSi8TCcBC

haddock-interfaces:   /usr/share/doc/haskell-pipes/html/pipes.haddock
haddock-html:         /usr/share/doc/haskell-pipes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
